@@ -258,7 +258,7 @@ eel_debug_draw_rectangle_and_cross (GdkDrawable *drawable,
 			       rectangle.y0 + height - 1);
 	}
 
-	gdk_gc_unref (gc);
+	g_object_unref (gc);
 }
 
 /**
