@@ -30,6 +30,7 @@
 #include "eel-debug-drawing.h"
 #include "eel-gtk-extensions.h"
 #include "eel-gtk-macros.h"
+#include "eel-labeled-image.h"
 #include "eel-marshal.h"
 #include "eel-region.h"
 #include <gtk/gtkmain.h>
@@ -112,14 +113,9 @@ static int     ancestor_button_release_event        (GtkWidget          *widget,
 						     GdkEventButton     *event,
 						     gpointer            event_data);
 
-/* EelImageTable signals */
-static void    eel_image_table_set_is_smooth_signal (GtkWidget          *widget,
-						     gboolean            is_smooth);
-
 EEL_CLASS_BOILERPLATE (EelImageTable, eel_image_table, EEL_TYPE_WRAP_TABLE)
 
-/* Class init methods */
-	static void
+static void
 eel_image_table_class_init (EelImageTableClass *image_table_class)
 {
 	GObjectClass *object_class = G_OBJECT_CLASS (image_table_class);
@@ -138,67 +134,57 @@ eel_image_table_class_init (EelImageTableClass *image_table_class)
 	container_class->remove = eel_image_table_remove;
 	container_class->child_type = eel_image_table_child_type;
 
-	/* EelImageTableClass */
-	image_table_class->set_is_smooth = eel_image_table_set_is_smooth_signal;
-	
 	/* Signals */
-	image_table_signals[CHILD_ENTER] = gtk_signal_new ("child_enter",
-							   GTK_RUN_LAST,
-							   GTK_CLASS_TYPE (object_class),
-							   G_STRUCT_OFFSET (EelImageTableClass, child_enter),
+	image_table_signals[CHILD_ENTER] = g_signal_new ("child_enter",
+							 G_TYPE_FROM_CLASS (object_class),
+							 G_SIGNAL_RUN_LAST,
+							 G_STRUCT_OFFSET (EelImageTableClass, child_enter),
+							 NULL, NULL,
+							 eel_marshal_VOID__OBJECT_POINTER,
+							 G_TYPE_NONE,
+							 2,
+							 GTK_TYPE_WIDGET,
+							 G_TYPE_POINTER);
+	image_table_signals[CHILD_LEAVE] = g_signal_new ("child_leave",
+							 G_TYPE_FROM_CLASS (object_class),
+							 G_SIGNAL_RUN_LAST,
+							 G_STRUCT_OFFSET (EelImageTableClass, child_leave),
+							 NULL, NULL,
+							 eel_marshal_VOID__OBJECT_POINTER,
+							 G_TYPE_NONE,
+							 2,
+							 GTK_TYPE_WIDGET,
+							 G_TYPE_POINTER);
+	image_table_signals[CHILD_PRESSED] = g_signal_new ("child_pressed",
+							   G_TYPE_FROM_CLASS (object_class),
+							   G_SIGNAL_RUN_LAST,
+							   G_STRUCT_OFFSET (EelImageTableClass, child_pressed),
+							   NULL, NULL,
 							   eel_marshal_VOID__OBJECT_POINTER,
 							   G_TYPE_NONE,
 							   2,
 							   GTK_TYPE_WIDGET,
 							   G_TYPE_POINTER);
-	image_table_signals[CHILD_LEAVE] = gtk_signal_new ("child_leave",
-							   GTK_RUN_LAST,
-							   GTK_CLASS_TYPE (object_class),
-							   G_STRUCT_OFFSET (EelImageTableClass, child_leave),
+	image_table_signals[CHILD_RELEASED] = g_signal_new ("child_released",
+							    G_TYPE_FROM_CLASS (object_class),
+							    G_SIGNAL_RUN_LAST,
+							    G_STRUCT_OFFSET (EelImageTableClass, child_released),
+							    NULL, NULL,
+							    eel_marshal_VOID__OBJECT_POINTER,
+							    G_TYPE_NONE,
+							    2,
+							    GTK_TYPE_WIDGET,
+							    G_TYPE_POINTER);
+	image_table_signals[CHILD_CLICKED] = g_signal_new ("child_clicked",
+							   G_TYPE_FROM_CLASS (object_class),
+							   G_SIGNAL_RUN_LAST,
+							   G_STRUCT_OFFSET (EelImageTableClass, child_clicked),
+							   NULL, NULL,
 							   eel_marshal_VOID__OBJECT_POINTER,
 							   G_TYPE_NONE,
 							   2,
 							   GTK_TYPE_WIDGET,
 							   G_TYPE_POINTER);
-	image_table_signals[CHILD_PRESSED] = gtk_signal_new ("child_pressed",
-							     GTK_RUN_LAST,
-							     GTK_CLASS_TYPE (object_class),
-							     G_STRUCT_OFFSET (EelImageTableClass, child_pressed),
-							     eel_marshal_VOID__OBJECT_POINTER,
-							     G_TYPE_NONE,
-							     2,
-							     GTK_TYPE_WIDGET,
-							     G_TYPE_POINTER);
-	image_table_signals[CHILD_RELEASED] = gtk_signal_new ("child_released",
-							      GTK_RUN_LAST,
-							      GTK_CLASS_TYPE (object_class),
-							      G_STRUCT_OFFSET (EelImageTableClass, child_released),
-							      eel_marshal_VOID__OBJECT_POINTER,
-							      G_TYPE_NONE,
-							      2,
-							      GTK_TYPE_WIDGET,
-							      G_TYPE_POINTER);
-	image_table_signals[CHILD_CLICKED] = gtk_signal_new ("child_clicked",
-							     GTK_RUN_LAST,
-							     GTK_CLASS_TYPE (object_class),
-							     G_STRUCT_OFFSET (EelImageTableClass, child_clicked),
-							     eel_marshal_VOID__OBJECT_POINTER,
-							     G_TYPE_NONE,
-							     2,
-							     GTK_TYPE_WIDGET,
-							     G_TYPE_POINTER);
-	
-	image_table_signals[SET_IS_SMOOTH] = gtk_signal_new ("set_is_smooth",
-							     GTK_RUN_LAST,
-							     GTK_CLASS_TYPE (object_class),
-							     G_STRUCT_OFFSET (EelImageTableClass, set_is_smooth),
-							     gtk_marshal_VOID__BOOLEAN,
-							     G_TYPE_NONE, 
-							     1,
-							     G_TYPE_BOOLEAN);
-
-	/* Let the smooth widget machinery know that our class can be smooth */
-	eel_smooth_widget_register_type (EEL_TYPE_IMAGE_TABLE);
 }
 
 void
@@ -208,8 +194,6 @@ eel_image_table_init (EelImageTable *image_table)
 
 	image_table->details = g_new0 (EelImageTableDetails, 1);
 	image_table->details->smooth_background_color = EEL_RGB_COLOR_WHITE;
-
-	eel_smooth_widget_register (GTK_WIDGET (image_table));
 }
 
 /* GObjectClass methods */
@@ -314,7 +298,7 @@ eel_image_table_unrealize (GtkWidget *widget)
 	image_table = EEL_IMAGE_TABLE (widget);
 
 	if (image_table->details->clear_gc != NULL) {
-		gdk_gc_unref (image_table->details->clear_gc);
+		g_object_unref (image_table->details->clear_gc);
 		image_table->details->clear_gc = NULL;
 	}
 
@@ -351,16 +335,6 @@ eel_image_table_child_type (GtkContainer *container)
 	return EEL_TYPE_LABELED_IMAGE;
 }
 
-/* EelImageTable signals */
-static void
-eel_image_table_set_is_smooth_signal (GtkWidget *widget,
-				      gboolean is_smooth)
-{
-	g_return_if_fail (EEL_IS_IMAGE_TABLE (widget));
-	
-	eel_image_table_set_is_smooth (EEL_IMAGE_TABLE (widget), is_smooth);
-}
-
 /* Private EelImageTable methods */
 
 /* For each of the image table children, subtract their content from a region */
@@ -693,25 +667,6 @@ eel_image_table_new (gboolean homogeneous)
 	return GTK_WIDGET (image_table);
 }
 
-/**
- * eel_image_table_set_is_smooth:
- * @image_table: A EelImageTable.
- * @is_smooth: Boolean value indicating whether the image table is smooth.
- *
- */
-void
-eel_image_table_set_is_smooth (EelImageTable *image_table,
-			       gboolean is_smooth)
-{
-	g_return_if_fail (EEL_IS_IMAGE_TABLE (image_table));
-	
-	if (image_table->details->is_smooth == is_smooth) {
-		return;
-	}
-	
-	image_table->details->is_smooth = is_smooth;
-}
-
 /**
  * eel_image_table_set_smooth_background_color:
  * @image_table: A EelImageTable.
