@@ -23,6 +23,7 @@
 */
 
 #include <config.h>
+#include <libgnome/gnome-i18n.h>
 #include "eel-labeled-image.h"
 
 #include "eel-art-extensions.h"
@@ -46,18 +47,18 @@
 /* Arguments */
 enum
 {
-	ARG_0,
-	ARG_FILL,
-	ARG_LABEL,
-	ARG_LABEL_POSITION,
-	ARG_PIXBUF,
-	ARG_SHOW_IMAGE,
-	ARG_SHOW_LABEL,
-	ARG_SPACING,
-	ARG_X_ALIGNMENT,
-	ARG_X_PADDING,
-	ARG_Y_ALIGNMENT,
-	ARG_Y_PADDING,
+	PROP_0,
+	PROP_FILL,
+	PROP_LABEL,
+	PROP_LABEL_POSITION,
+	PROP_PIXBUF,
+	PROP_SHOW_IMAGE,
+	PROP_SHOW_LABEL,
+	PROP_SPACING,
+	PROP_X_ALIGNMENT,
+	PROP_X_PADDING,
+	PROP_Y_ALIGNMENT,
+	PROP_Y_PADDING,
 };
 
 /* Detail member struct */
@@ -81,13 +82,15 @@ static void          eel_labeled_image_class_init   (EelLabeledImageClass  *labe
 static void          eel_labeled_image_init         (EelLabeledImage       *image);
 static void          eel_labeled_image_finalize           (GObject               *object);
 
-/* GtkObjectClass methods */
-static void          eel_labeled_image_set_arg            (GtkObject             *object,
-							   GtkArg                *arg,
-							   guint                  arg_id);
-static void          eel_labeled_image_get_arg            (GtkObject             *object,
-							   GtkArg                *arg,
-							   guint                  arg_id);
+/* GObjectClass methods */
+static void          eel_labeled_image_set_property       (GObject               *object,
+							   guint                  property_id,
+							   const GValue          *value,
+							   GParamSpec            *pspec);
+static void          eel_labeled_image_get_property       (GObject               *object,
+							   guint                  property_id,
+							   GValue                *value,
+							   GParamSpec            *pspec);
 /* GtkWidgetClass methods */
 static void          eel_labeled_image_size_request       (GtkWidget             *widget,
 							   GtkRequisition        *requisition);
@@ -125,15 +128,15 @@ EEL_CLASS_BOILERPLATE (EelLabeledImage, eel_labeled_image, GTK_TYPE_CONTAINER)
 static void
 eel_labeled_image_class_init (EelLabeledImageClass *labeled_image_class)
 {
-	GtkObjectClass *object_class = GTK_OBJECT_CLASS (labeled_image_class);
+	GObjectClass *gobject_class = G_OBJECT_CLASS (labeled_image_class);
 	GtkWidgetClass *widget_class = GTK_WIDGET_CLASS (labeled_image_class);
 	GtkContainerClass *container_class = GTK_CONTAINER_CLASS (labeled_image_class);
 
-	G_OBJECT_CLASS (object_class)->finalize = eel_labeled_image_finalize;
+	gobject_class->finalize = eel_labeled_image_finalize;
 
-	/* GtkObjectClass */
-	object_class->set_arg = eel_labeled_image_set_arg;
-	object_class->get_arg = eel_labeled_image_get_arg;
+	/* GObjectClass */
+	gobject_class->set_property = eel_labeled_image_set_property;
+	gobject_class->get_property = eel_labeled_image_get_property;
 	
  	/* GtkWidgetClass */
  	widget_class->size_request = eel_labeled_image_size_request;
@@ -147,51 +150,108 @@ eel_labeled_image_class_init (EelLabeledImageClass *labeled_image_class)
 	container_class->remove = eel_labeled_image_remove;
 	container_class->forall = eel_labeled_image_forall;
   
-	/* Arguments */
-	gtk_object_add_arg_type ("EelLabeledImage::pixbuf",
-				 G_TYPE_POINTER,
-				 GTK_ARG_READWRITE,
-				 ARG_PIXBUF);
-	gtk_object_add_arg_type ("EelLabeledImage::label",
-				 GTK_TYPE_STRING,
-				 GTK_ARG_READWRITE,
-				 ARG_LABEL);
-	gtk_object_add_arg_type ("EelLabeledImage::label_position",
-				 GTK_TYPE_POSITION_TYPE,
-				 GTK_ARG_READWRITE,
-				 ARG_LABEL_POSITION);
-	gtk_object_add_arg_type ("EelLabeledImage::show_label",
-				 G_TYPE_BOOLEAN,
-				 GTK_ARG_READWRITE,
-				 ARG_SHOW_LABEL);
-	gtk_object_add_arg_type ("EelLabeledImage::show_image",
-				 G_TYPE_BOOLEAN,
-				 GTK_ARG_READWRITE,
-				 ARG_SHOW_IMAGE);
-	gtk_object_add_arg_type ("EelLabeledImage::spacing",
-				 G_TYPE_UINT,
-				 GTK_ARG_READWRITE,
-				 ARG_SPACING);
-	gtk_object_add_arg_type ("EelLabeledImage::x_padding",
-				 G_TYPE_INT,
-				 GTK_ARG_READWRITE,
-				 ARG_X_PADDING);
-	gtk_object_add_arg_type ("EelLabeledImage::y_padding",
-				 G_TYPE_INT,
-				 GTK_ARG_READWRITE,
-				 ARG_Y_PADDING);
-	gtk_object_add_arg_type ("EelLabeledImage::x_alignment",
-				 G_TYPE_FLOAT,
-				 GTK_ARG_READWRITE,
-				 ARG_X_ALIGNMENT);
-	gtk_object_add_arg_type ("EelLabeledImage::y_alignment",
-				 G_TYPE_FLOAT,
-				 GTK_ARG_READWRITE,
-				 ARG_Y_ALIGNMENT);
-	gtk_object_add_arg_type ("EelLabeledImage::fill",
-				 G_TYPE_BOOLEAN,
-				 GTK_ARG_READWRITE,
-				 ARG_FILL);
+	/* Properties */
+        g_object_class_install_property (
+		gobject_class,
+		PROP_PIXBUF,
+		g_param_spec_object ("pixbuf", _("pixbuf"), _("the image"),
+				     GDK_TYPE_PIXBUF, G_PARAM_READWRITE));
+
+        g_object_class_install_property (
+		gobject_class,
+		PROP_LABEL,
+		g_param_spec_string ("label", _("label"), _("the label"),
+				     "", G_PARAM_READWRITE));
+
+
+        g_object_class_install_property (
+		gobject_class,
+		PROP_LABEL_POSITION,
+		g_param_spec_enum ("label_position",
+				   _("position"), _("the label position"),
+				   GTK_TYPE_POSITION_TYPE,
+				   GTK_POS_BOTTOM,
+				   G_PARAM_READWRITE));
+
+        g_object_class_install_property (
+		gobject_class,
+		PROP_SHOW_LABEL,
+		g_param_spec_boolean ("show_label",
+				      _("label visible"),
+				      _("whether to show the label"),
+				      TRUE, G_PARAM_READWRITE)); 
+				   
+        g_object_class_install_property (
+		gobject_class,
+		PROP_SHOW_IMAGE,
+		g_param_spec_boolean ("show_image",
+				      _("image visible"),
+				      _("whether to show the image"),
+				      TRUE, G_PARAM_READWRITE)); 
+				   
+
+	g_object_class_install_property (
+		gobject_class,
+		PROP_SPACING,
+		g_param_spec_uint ("spacing",
+				   _("Spacing"),
+				   _("The amount of space between the items."),
+				   0,
+				   G_MAXINT,
+				   DEFAULT_SPACING,
+				   G_PARAM_READWRITE));
+
+	g_object_class_install_property (
+		gobject_class,
+		PROP_X_PADDING,
+		g_param_spec_int ("x_padding",
+				  _("X padding"),
+				  _("the amount of horizontal padding space."),
+				  0,
+				  G_MAXINT,
+				  DEFAULT_X_PADDING,
+				  G_PARAM_READWRITE));
+
+	g_object_class_install_property (
+		gobject_class,
+		PROP_Y_PADDING,
+		g_param_spec_int ("y_padding",
+				  _("Y padding"),
+				  _("the amount of vertical padding space"),
+				  0,
+				  G_MAXINT,
+				  DEFAULT_Y_PADDING,
+				  G_PARAM_READWRITE));
+
+	g_object_class_install_property (
+		gobject_class,
+		PROP_X_ALIGNMENT,
+		g_param_spec_float ("x_alignment",
+				    _("Horizontal alignment"),
+				    _("Horizontal position of child in available space. 0.0 is left aligned, 1.0 is right aligned"),
+				    0.0,
+				    1.0,
+				    DEFAULT_X_ALIGNMENT,
+				    G_PARAM_READWRITE));
+   
+	g_object_class_install_property (
+		gobject_class,
+		PROP_Y_ALIGNMENT,
+		g_param_spec_float ("y_alignment",
+				    _("Vertical alignment"),
+				    _("Vertical position of child in available space. 0.0 is top aligned, 1.0 is bottom aligned"),
+				    0.0,
+				    1.0,
+				    DEFAULT_Y_ALIGNMENT,
+				    G_PARAM_READWRITE));
+
+	g_object_class_install_property (
+		gobject_class,
+		PROP_FILL,
+		g_param_spec_boolean ("fill", _("fill"),
+				      _("expand to fill allocation"),
+				      FALSE,
+				      G_PARAM_READWRITE));
 }
 
 void
@@ -225,11 +285,13 @@ eel_labeled_image_finalize (GObject *object)
 	EEL_CALL_PARENT (G_OBJECT_CLASS, finalize, (object));
 }
 
-/* GtkObjectClass methods */
+
+/* GObjectClass methods */
 static void
-eel_labeled_image_set_arg (GtkObject *object,
-			   GtkArg *arg,
-			   guint arg_id)
+eel_labeled_image_set_property (GObject      *object,
+				guint         property_id,
+				const GValue *value,
+				GParamSpec   *pspec)
 {
 	EelLabeledImage *labeled_image;
 	
@@ -237,50 +299,60 @@ eel_labeled_image_set_arg (GtkObject *object,
 
  	labeled_image = EEL_LABELED_IMAGE (object);
 
- 	switch (arg_id)
+ 	switch (property_id)
 	{
-	case ARG_PIXBUF:
-		eel_labeled_image_set_pixbuf (labeled_image, (GdkPixbuf *) GTK_VALUE_POINTER (*arg));
+	case PROP_PIXBUF:
+		eel_labeled_image_set_pixbuf (labeled_image,
+					      g_value_get_object (value));
 		break;
 
-	case ARG_LABEL:
-		eel_labeled_image_set_text (labeled_image, GTK_VALUE_STRING (*arg));
+	case PROP_LABEL:
+		eel_labeled_image_set_text (labeled_image, g_value_get_string (value));
 		break;
 
-	case ARG_LABEL_POSITION:
-		eel_labeled_image_set_label_position (labeled_image, GTK_VALUE_ENUM (*arg));
+	case PROP_LABEL_POSITION:
+		eel_labeled_image_set_label_position (labeled_image,
+						      g_value_get_enum (value));
 		break;
 
-	case ARG_SHOW_LABEL:
-		eel_labeled_image_set_show_label (labeled_image, GTK_VALUE_BOOL (*arg));
+	case PROP_SHOW_LABEL:
+		eel_labeled_image_set_show_label (labeled_image,
+						  g_value_get_boolean (value));
 		break;
 
-	case ARG_SHOW_IMAGE:
-		eel_labeled_image_set_show_image (labeled_image, GTK_VALUE_BOOL (*arg));
+	case PROP_SHOW_IMAGE:
+		eel_labeled_image_set_show_image (labeled_image,
+						  g_value_get_boolean (value));
 		break;
 
-	case ARG_SPACING:
-		eel_labeled_image_set_spacing (labeled_image, GTK_VALUE_UINT (*arg));
+	case PROP_SPACING:
+		eel_labeled_image_set_spacing (labeled_image,
+					       g_value_get_uint (value));
 		break;
 
-	case ARG_X_PADDING:
-		eel_labeled_image_set_x_padding (labeled_image, GTK_VALUE_INT (*arg));
+	case PROP_X_PADDING:
+		eel_labeled_image_set_x_padding (labeled_image,
+						 g_value_get_int (value));
 		break;
 
-	case ARG_Y_PADDING:
-		eel_labeled_image_set_y_padding (labeled_image, GTK_VALUE_INT (*arg));
+	case PROP_Y_PADDING:
+		eel_labeled_image_set_y_padding (labeled_image,
+						 g_value_get_int (value));
 		break;
 
-	case ARG_X_ALIGNMENT:
-		eel_labeled_image_set_x_alignment (labeled_image, GTK_VALUE_FLOAT (*arg));
+	case PROP_X_ALIGNMENT:
+		eel_labeled_image_set_x_alignment (labeled_image,
+						   g_value_get_float (value));
 		break;
 
-	case ARG_Y_ALIGNMENT:
-		eel_labeled_image_set_y_alignment (labeled_image, GTK_VALUE_FLOAT (*arg));
+	case PROP_Y_ALIGNMENT:
+		eel_labeled_image_set_y_alignment (labeled_image,
+						   g_value_get_float (value));
 		break;
 
-	case ARG_FILL:
-		eel_labeled_image_set_fill (labeled_image, GTK_VALUE_BOOL (*arg));
+	case PROP_FILL:
+		eel_labeled_image_set_fill (labeled_image,
+					    g_value_get_boolean (value));
 		break;
  	default:
 		g_assert_not_reached ();
@@ -288,9 +360,10 @@ eel_labeled_image_set_arg (GtkObject *object,
 }
 
 static void
-eel_labeled_image_get_arg (GtkObject *object,
-			   GtkArg *arg,
-			   guint arg_id)
+eel_labeled_image_get_property (GObject    *object,
+				guint       property_id,
+				GValue     *value,
+				GParamSpec *pspec)
 {
 	EelLabeledImage *labeled_image;
 
@@ -298,46 +371,52 @@ eel_labeled_image_get_arg (GtkObject *object,
 	
 	labeled_image = EEL_LABELED_IMAGE (object);
 
- 	switch (arg_id)
+ 	switch (property_id)
 	{
-	case ARG_LABEL:
-		GTK_VALUE_STRING (*arg) = eel_labeled_image_get_text (labeled_image);
+	case PROP_LABEL:
+		if (labeled_image->details->label == NULL) {
+			g_value_set_string (value, NULL);
+		} else {
+			g_value_set_string (value, 
+					    gtk_label_get_text (GTK_LABEL (
+						    labeled_image->details->label)));
+		}
 		break;
 
-	case ARG_LABEL_POSITION:
-		GTK_VALUE_ENUM (*arg) = eel_labeled_image_get_label_position (labeled_image);
+	case PROP_LABEL_POSITION:
+		g_value_set_enum (value, eel_labeled_image_get_label_position (labeled_image));
 		break;
 
-	case ARG_SHOW_LABEL:
-		GTK_VALUE_BOOL (*arg) = eel_labeled_image_get_show_label (labeled_image);
+	case PROP_SHOW_LABEL:
+		g_value_set_boolean (value, eel_labeled_image_get_show_label (labeled_image));
 		break;
 
-	case ARG_SHOW_IMAGE:
-		GTK_VALUE_BOOL (*arg) = eel_labeled_image_get_show_image (labeled_image);
+	case PROP_SHOW_IMAGE:
+		g_value_set_boolean (value, eel_labeled_image_get_show_image (labeled_image));
 		break;
 
-	case ARG_SPACING:
-		GTK_VALUE_UINT (*arg) = eel_labeled_image_get_spacing (labeled_image);
+	case PROP_SPACING:
+		g_value_set_uint (value, eel_labeled_image_get_spacing (labeled_image));
 		break;
 
-	case ARG_X_PADDING:
-		GTK_VALUE_INT (*arg) = eel_labeled_image_get_x_padding (labeled_image);
+	case PROP_X_PADDING:
+		g_value_set_int (value, eel_labeled_image_get_x_padding (labeled_image));
 		break;
 
-	case ARG_Y_PADDING:
-		GTK_VALUE_INT (*arg) = eel_labeled_image_get_y_padding (labeled_image);
+	case PROP_Y_PADDING:
+		g_value_set_int (value, eel_labeled_image_get_y_padding (labeled_image));
 		break;
 
-	case ARG_X_ALIGNMENT:
-		GTK_VALUE_FLOAT (*arg) = eel_labeled_image_get_x_alignment (labeled_image);
+	case PROP_X_ALIGNMENT:
+		g_value_set_float (value, eel_labeled_image_get_x_alignment (labeled_image));
 		break;
 
-	case ARG_Y_ALIGNMENT:
-		GTK_VALUE_FLOAT (*arg) = eel_labeled_image_get_y_alignment (labeled_image);
+	case PROP_Y_ALIGNMENT:
+		g_value_set_float (value, eel_labeled_image_get_y_alignment (labeled_image));
 		break;
 
-	case ARG_FILL:
-		GTK_VALUE_BOOL (*arg) = eel_labeled_image_get_fill (labeled_image);
+	case PROP_FILL:
+		g_value_set_boolean (value, eel_labeled_image_get_fill (labeled_image));
 		break;
 
  	default:
@@ -1685,16 +1764,10 @@ eel_labeled_image_check_button_new (const char *text,
 	 * Workaround some bugs in GtkCheckButton where the widget 
 	 * does not redraw properly after leave or focus out events
 	 */
-	gtk_signal_connect_while_alive (GTK_OBJECT (check_button),
-					"leave",
-					G_CALLBACK (button_leave_callback),
-					NULL,
-					GTK_OBJECT (check_button));
-	gtk_signal_connect_while_alive (GTK_OBJECT (check_button),
-					"focus_out_event",
-					G_CALLBACK (button_focus_out_event_callback),
-					NULL,
-					GTK_OBJECT (check_button));
+	g_signal_connect (check_button, "leave",
+			  G_CALLBACK (button_leave_callback), NULL);
+	g_signal_connect (check_button, "focus_out_event",
+			  G_CALLBACK (button_focus_out_event_callback), NULL);
 	
 	return check_button;
 }
