@@ -83,13 +83,14 @@ eel_string_picker_class_init (EelStringPickerClass *string_picker_class)
 	object_class->finalize = eel_string_picker_finalize;
 	
 	/* Signals */
-	string_picker_signals[CHANGED] = gtk_signal_new ("changed",
-							 G_SIGNAL_RUN_LAST,
-							 GTK_CLASS_TYPE (object_class),
-							 G_STRUCT_OFFSET (EelStringPickerClass, changed),
-							 gtk_marshal_VOID__VOID,
-							 G_TYPE_NONE, 
-							 0);
+	string_picker_signals[CHANGED] = g_signal_new ("changed",
+						       G_TYPE_FROM_CLASS (object_class),
+						       G_SIGNAL_RUN_LAST,
+						       G_STRUCT_OFFSET (EelStringPickerClass, changed),
+						       NULL, NULL,
+						       g_cclosure_marshal_VOID__VOID,
+						       G_TYPE_NONE, 
+						       0);
 }
 
 static void
