@@ -87,13 +87,14 @@ eel_text_caption_class_init (EelTextCaptionClass *text_caption_class)
 	
 	/* Signals */
 	text_caption_signals[CHANGED] =
-		gtk_signal_new ("changed",
-				G_SIGNAL_RUN_LAST,
-				GTK_CLASS_TYPE (object_class),
-				G_STRUCT_OFFSET (EelTextCaptionClass, changed),
-				gtk_marshal_VOID__VOID,
-				G_TYPE_NONE, 
-				0);
+		g_signal_new ("changed",
+			      G_TYPE_FROM_CLASS (object_class),
+			      G_SIGNAL_RUN_LAST,
+			      G_STRUCT_OFFSET (EelTextCaptionClass, changed),
+			      NULL, NULL,
+			      g_cclosure_marshal_VOID__VOID,
+			      G_TYPE_NONE, 
+			      0);
 }
 
 static void
@@ -106,7 +107,7 @@ eel_text_caption_init (EelTextCaption *text_caption)
 
 	text_caption->detail->text = gtk_entry_new ();
 	
-	gtk_entry_set_editable (GTK_ENTRY (text_caption->detail->text), TRUE);
+	gtk_editable_set_editable (GTK_EDITABLE (text_caption->detail->text), TRUE);
 	gtk_entry_set_activates_default (GTK_ENTRY (text_caption->detail->text), TRUE);
 	
 	eel_caption_set_child (EEL_CAPTION (text_caption),
@@ -118,10 +119,10 @@ eel_text_caption_init (EelTextCaption *text_caption)
 			    "changed",
 			    G_CALLBACK (entry_changed_callback),
 			    (gpointer) text_caption);
-	gtk_signal_connect_after (GTK_OBJECT (text_caption->detail->text),
-				  "key_press_event",
-				  G_CALLBACK (entry_key_press_callback),
-				  (gpointer) text_caption);
+	g_signal_connect_after (G_OBJECT (text_caption->detail->text),
+				"key_press_event",
+				G_CALLBACK (entry_key_press_callback),
+				(gpointer) text_caption);
 
 	gtk_widget_show (text_caption->detail->text);
 }
@@ -219,11 +220,11 @@ eel_text_caption_set_text (EelTextCaption	*text_caption,
 
 void
 eel_text_caption_set_editable (EelTextCaption *text_caption,
-				    gboolean editable)
+			       gboolean        editable)
 {
 	g_return_if_fail (EEL_IS_TEXT_CAPTION (text_caption));
 
-	gtk_entry_set_editable (GTK_ENTRY (text_caption->detail->text), editable);
+	gtk_editable_set_editable (GTK_EDITABLE (text_caption->detail->text), editable);
 }
 
 void
