@@ -33,16 +33,17 @@
 
 #include <gtk/gtkmain.h>
 #include <gtk/gtkviewport.h>
+#include <libgnome/gnome-i18n.h>
 
 /* Arguments */
 enum
 {
-	ARG_0,
-	ARG_X_SPACING,
-	ARG_Y_SPACING,
-	ARG_X_JUSTIFICATION,
-	ARG_Y_JUSTIFICATION,
-	ARG_HOMOGENEOUS,
+	PROP_0,
+	PROP_X_SPACING,
+	PROP_Y_SPACING,
+	PROP_X_JUSTIFICATION,
+	PROP_Y_JUSTIFICATION,
+	PROP_HOMOGENEOUS,
 };
 
 /* Detail member struct */
@@ -56,17 +57,18 @@ struct EelWrapTableDetails
 	GList *children;
 };
 
-static void          eel_wrap_table_class_init     (EelWrapTableClass   *wrap_table_class);
-static void          eel_wrap_table_init           (EelWrapTable        *wrap);
+static void          eel_wrap_table_class_init           (EelWrapTableClass   *wrap_table_class);
+static void          eel_wrap_table_init                 (EelWrapTable        *wrap);
+/* GObjectClass methods */
 static void          eel_wrap_table_finalize             (GObject             *object);
-
-/* GtkObjectClass methods */
-static void          eel_wrap_table_set_arg              (GtkObject           *object,
-							  GtkArg              *arg,
-							  guint                arg_id);
-static void          eel_wrap_table_get_arg              (GtkObject           *object,
-							  GtkArg              *arg,
-							  guint                arg_id);
+static void          eel_wrap_table_set_property         (GObject             *object,
+							  guint                property_id,
+							  const GValue        *value,
+							  GParamSpec          *pspec);
+static void          eel_wrap_table_get_property         (GObject             *object,
+							  guint                property_id,
+							  GValue              *value,
+							  GParamSpec          *pspec);
 /* GtkWidgetClass methods */
 static void          eel_wrap_table_size_request         (GtkWidget           *widget,
 							  GtkRequisition      *requisition);
@@ -107,15 +109,14 @@ EEL_CLASS_BOILERPLATE (EelWrapTable, eel_wrap_table, GTK_TYPE_CONTAINER)
 static void
 eel_wrap_table_class_init (EelWrapTableClass *wrap_table_class)
 {
-	GtkObjectClass *object_class = GTK_OBJECT_CLASS (wrap_table_class);
+	GObjectClass *gobject_class = G_OBJECT_CLASS (wrap_table_class);
 	GtkWidgetClass *widget_class = GTK_WIDGET_CLASS (wrap_table_class);
 	GtkContainerClass *container_class = GTK_CONTAINER_CLASS (wrap_table_class);
 
-	G_OBJECT_CLASS (wrap_table_class)->finalize = eel_wrap_table_finalize;
-
-	/* GtkObjectClass */
-	object_class->set_arg = eel_wrap_table_set_arg;
-	object_class->get_arg = eel_wrap_table_get_arg;
+	/* GObjectClass */
+	gobject_class->finalize = eel_wrap_table_finalize;
+	gobject_class->set_property = eel_wrap_table_set_property;
+	gobject_class->get_property = eel_wrap_table_get_property;
 	
  	/* GtkWidgetClass */
  	widget_class->size_request = eel_wrap_table_size_request;
@@ -129,30 +130,48 @@ eel_wrap_table_class_init (EelWrapTableClass *wrap_table_class)
 	container_class->remove = eel_wrap_table_remove;
 	container_class->forall = eel_wrap_table_forall;
 	container_class->child_type = eel_wrap_table_child_type;
-  
+
 	/* Arguments */
-	gtk_object_add_arg_type ("EelWrapTable::x_spacing",
-				 G_TYPE_UINT,
-				 GTK_ARG_READWRITE,
-				 ARG_X_SPACING);
-	gtk_object_add_arg_type ("EelWrapTable::y_spacing",
-				 G_TYPE_UINT,
-				 GTK_ARG_READWRITE,
-				 ARG_Y_SPACING);
+	g_object_class_install_property (
+		gobject_class,
+		PROP_X_SPACING,
+		g_param_spec_uint ("x_spacing",
+				   _("X spacing"),
+				   _("The amount of horizontal spacing."),
+				   0,
+				   G_MAXINT,
+				   0,
+				   G_PARAM_READWRITE));
+
+	g_object_class_install_property (
+		gobject_class,
+		PROP_Y_SPACING,
+		g_param_spec_uint ("y_spacing",
+				   _("Y spacing"),
+				   _("The amount of vertical spacing."),
+				   0,
+				   G_MAXINT,
+				   0,
+				   G_PARAM_READWRITE));
+
 #if GNOME2_CONVERSION_COMPLETE
 	gtk_object_add_arg_type ("EelWrapTable::x_justification",
 				 G_TYPE_ENUM,
-				 GTK_ARG_READWRITE,
-				 ARG_X_JUSTIFICATION);
+				 GTK_PROP_READWRITE,
+				 PROP_X_JUSTIFICATION);
 	gtk_object_add_arg_type ("EelWrapTable::y_justification",
 				 G_TYPE_ENUM,
-				 GTK_ARG_READWRITE,
-				 ARG_Y_JUSTIFICATION);
+				 GTK_PROP_READWRITE,
+				 PROP_Y_JUSTIFICATION);
 #endif
-	gtk_object_add_arg_type ("EelWrapTable::homogeneous",
-				 G_TYPE_BOOLEAN,
-				 GTK_ARG_READWRITE,
-				 ARG_HOMOGENEOUS);
+	g_object_class_install_property (
+		gobject_class,
+		PROP_HOMOGENEOUS,
+		g_param_spec_boolean ("homogenous",
+				      _("homogenous"),
+				      _("homogeneous layout"),
+				      FALSE,
+				      G_PARAM_READWRITE));
 }
 
 void
@@ -178,12 +197,13 @@ eel_wrap_table_finalize (GObject *object)
 	EEL_CALL_PARENT (G_OBJECT_CLASS, finalize, (object));
 }
 
-/* GtkObjectClass methods */
+/* GObjectClass methods */
 
 static void
-eel_wrap_table_set_arg (GtkObject *object,
-			     GtkArg *arg,
-			     guint arg_id)
+eel_wrap_table_set_property (GObject      *object,
+			     guint         property_id,
+			     const GValue *value,
+			     GParamSpec   *pspec)
 {
 	EelWrapTable *wrap_table;
 	
@@ -191,26 +211,26 @@ eel_wrap_table_set_arg (GtkObject *object,
 
  	wrap_table = EEL_WRAP_TABLE (object);
 
- 	switch (arg_id)
+ 	switch (property_id)
 	{
-	case ARG_X_SPACING:
-		eel_wrap_table_set_x_spacing (wrap_table, GTK_VALUE_UINT (*arg));
+	case PROP_X_SPACING:
+		eel_wrap_table_set_x_spacing (wrap_table, g_value_get_uint (value));
 		break;
 
-	case ARG_Y_SPACING:
-		eel_wrap_table_set_y_spacing (wrap_table, GTK_VALUE_UINT (*arg));
+	case PROP_Y_SPACING:
+		eel_wrap_table_set_y_spacing (wrap_table, g_value_get_uint (value));
 		break;
 
-	case ARG_X_JUSTIFICATION:
-		eel_wrap_table_set_x_justification (wrap_table, GTK_VALUE_ENUM (*arg));
+	case PROP_X_JUSTIFICATION:
+		eel_wrap_table_set_x_justification (wrap_table, g_value_get_enum (value));
 		break;
 
-	case ARG_Y_JUSTIFICATION:
-		eel_wrap_table_set_y_justification (wrap_table, GTK_VALUE_ENUM (*arg));
+	case PROP_Y_JUSTIFICATION:
+		eel_wrap_table_set_y_justification (wrap_table, g_value_get_enum (value));
 		break;
 
-	case ARG_HOMOGENEOUS:
-		eel_wrap_table_set_homogeneous (wrap_table, GTK_VALUE_BOOL (*arg));
+	case PROP_HOMOGENEOUS:
+		eel_wrap_table_set_homogeneous (wrap_table, g_value_get_boolean (value));
 		break;
 
  	default:
@@ -219,9 +239,10 @@ eel_wrap_table_set_arg (GtkObject *object,
 }
 
 static void
-eel_wrap_table_get_arg (GtkObject *object,
-			    GtkArg *arg,
-			    guint arg_id)
+eel_wrap_table_get_property (GObject    *object,
+			     guint       property_id,
+			     GValue     *value,
+			     GParamSpec *pspec)
 {
 	EelWrapTable *wrap_table;
 
@@ -229,26 +250,26 @@ eel_wrap_table_get_arg (GtkObject *object,
 	
 	wrap_table = EEL_WRAP_TABLE (object);
 
- 	switch (arg_id)
+ 	switch (property_id)
 	{
-	case ARG_X_SPACING:
-		GTK_VALUE_UINT (*arg) = eel_wrap_table_get_x_spacing (wrap_table);
+	case PROP_X_SPACING:
+		g_value_set_uint (value, eel_wrap_table_get_x_spacing (wrap_table));
 		break;
 
-	case ARG_Y_SPACING:
-		GTK_VALUE_UINT (*arg) = eel_wrap_table_get_y_spacing (wrap_table);
+	case PROP_Y_SPACING:
+		g_value_set_uint (value, eel_wrap_table_get_y_spacing (wrap_table));
 		break;
 
-	case ARG_X_JUSTIFICATION:
-		GTK_VALUE_ENUM (*arg) = eel_wrap_table_get_x_justification (wrap_table);
+	case PROP_X_JUSTIFICATION:
+		g_value_set_enum (value, eel_wrap_table_get_x_justification (wrap_table));
 		break;
 
-	case ARG_Y_JUSTIFICATION:
-		GTK_VALUE_ENUM (*arg) = eel_wrap_table_get_y_justification (wrap_table);
+	case PROP_Y_JUSTIFICATION:
+		g_value_set_enum (value, eel_wrap_table_get_y_justification (wrap_table));
 		break;
 
-	case ARG_HOMOGENEOUS:
-		GTK_VALUE_BOOL (*arg) = eel_wrap_table_get_homogeneous (wrap_table);
+	case PROP_HOMOGENEOUS:
+		g_value_set_boolean (value, eel_wrap_table_get_homogeneous (wrap_table));
 		break;
 
  	default:
