@@ -30,8 +30,6 @@
 #include <eel/eel-background.h>
 #include <eel/eel-caption-table.h>
 #include <eel/eel-caption.h>
-#include <eel/eel-clist.h>
-#include <eel/eel-ctree.h>
 #include <eel/eel-dateedit-extensions.h>
 #include <eel/eel-ellipsizing-label.h>
 #include <eel/eel-enumeration.h>
@@ -49,11 +47,8 @@
 #include <eel/eel-gtk-macros.h>
 #include <eel/eel-image-chooser.h>
 #include <eel/eel-image-table.h>
-#include <eel/eel-image-with-background.h>
-#include <eel/eel-image.h>
 #include <eel/eel-labeled-image.h>
-#include <eel/eel-list-column-title.h>
-#include <eel/eel-list.h>
+#include <eel/eel-pango-extensions.h>
 #include <eel/eel-password-dialog.h>
 #include <eel/eel-preferences-box.h>
 #include <eel/eel-preferences-group.h>
@@ -63,7 +58,6 @@
 #include <eel/eel-radio-button-group.h>
 #include <eel/eel-region.h>
 #include <eel/eel-self-checks.h>
-#include <eel/eel-smooth-widget.h>
 #include <eel/eel-stock-dialogs.h>
 #include <eel/eel-string-list.h>
 #include <eel/eel-string-picker.h>
@@ -71,7 +65,6 @@
 #include <eel/eel-text-caption.h>
 #include <eel/eel-types.h>
 #include <eel/eel-vfs-extensions.h>
-#include <eel/eel-viewport.h>
 #include <eel/eel-wrap-table.h>
 #include <eel/eel-xml-extensions.h>
 
